Low Level Utilities
===================

These functions can be imported from ``xmitgcm.utils``. They are meant for
internal use in xmitgcm, and users are recommended to use
``open_mdsdataset`` wherever possible (see :doc:`/usage`).

.. automodule:: xmitgcm.llcreader
   :members: 
